GMAT2test Data SetThe GMAT2key is a vector of factors representing correct answers of generated
GMAT2test data set based on Graduate Management Admission Test (GMAT) data set (Kingston et al., 1985).
data(GMAT2key)A data frame with 20 values representing correct answers to items of GMAT2test data set.
For more details see GMAT2test.
Kingston, N., Leary, L., & Wightman, L. (1985). An Exploratory Study of the Applicability of Item Response Theory Methods to the Graduate Management Admission Test. ETS Research Report Series, 1985(2) : 1-64.
Drabinova, A. & Martinkova P. (2017). Detection of Differential Item Functioning with NonLinear Regression: Non-IRT Approach Accounting for Guessing. Journal of Educational Measurement, 54(4), 498-517, https://doi.org/10.1111/jedm.12158.