The unconstrained form of 4PL generalized logistic regression model for probability of correct
answer (i.e., \(y = 1\)) is
$$P(y = 1) = (c + cDif*g) + (d + dDif*g - c - cDif*g)/(1 + exp(-(a + aDif*g)*(x - b - bDif*g))), $$
where \(x\) is by default standardized total score (also called Z-score) and \(g\) is a group membership.
Parameters \(a\), \(b\), \(c\), and \(d\) are discrimination, difficulty, guessing, and inattention.
Terms \(aDif\), \(bDif\), \(cDif\), and \(dDif\) then represent differences between two groups
(reference and focal) in relevant parameters.
The model argument offers several predefined models. The options are as follows:
Rasch for 1PL model with discrimination parameter fixed on value 1 for both groups,
1PL for 1PL model with discrimination parameter fixed for both groups,
2PL for logistic regression model,
3PLcg for 3PL model with fixed guessing for both groups,
3PLdg for 3PL model with fixed inattention for both groups,
3PLc (alternatively also 3PL) for 3PL regression model with guessing parameter,
3PLd for 3PL model with inattention parameter,
4PLcgdg for 4PL model with fixed guessing and inattention parameter for both groups,
4PLcgd (alternatively also 4PLd) for 4PL model with fixed guessing for both groups,
4PLcdg (alternatively also 4PLc) for 4PL model with fixed inattention for both groups,
or 4PL for 4PL model.
Three possible parameterization can be specified in "parameterization" argument: "classic"
returns IRT parameters of reference group and differences in these parameters between reference and focal group.
"alternative" returns IRT parameters of reference group, the differences in parameters "a" and
"b" between two groups and parameters "c" and "d" for focal group.
"logistic" returns parameters in logistic regression parameterization.